summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderseldlg.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/kmfolderseldlg.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmfolderseldlg.h')
-rw-r--r--kmail/kmfolderseldlg.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kmail/kmfolderseldlg.h b/kmail/kmfolderseldlg.h
index f1637a2f..81bdd7eb 100644
--- a/kmail/kmfolderseldlg.h
+++ b/kmail/kmfolderseldlg.h
@@ -21,17 +21,18 @@ namespace KMail {
class KMFolderSelDlg: public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor with KMMainWidget
* @p parent @em must be a KMMainWin, because we
* need its foldertree.
* @param mustBeReadWrite if true, readonly folders are disabled
* @param useGlobalSettings if true, the current folder is read and
* written to GlobalSettings
*/
- KMFolderSelDlg( KMMainWidget * parent, const TQString& caption,
+ KMFolderSelDlg( KMMainWidget * tqparent, const TQString& caption,
bool mustBeReadWrite, bool useGlobalSettings = true );
/**
* Constructor with separate KMFolderTree
@@ -39,7 +40,7 @@ namespace KMail {
* @param useGlobalSettings if true, the current folder is read and
* written to GlobalSettings
*/
- KMFolderSelDlg( TQWidget * parent, KMFolderTree * tree,
+ KMFolderSelDlg( TQWidget * tqparent, KMFolderTree * tree,
const TQString& caption, bool mustBeReadWrite,
bool useGlobalSettings = true );
@@ -57,7 +58,7 @@ namespace KMail {
protected slots:
void slotSelect();
void slotUser1();
- void slotUpdateBtnStatus();
+ void slotUpdateBtntqStatus();
protected:
void readConfig();
@@ -21,17 +21,18 @@ namespace KMail {
/**
* Constructor with KMMainWidget
- * @p parent @em must be a KMMainWin, because we
+ * @p tqparent @em must be a KMMainWin, because we
* need its foldertree.
* @param mustBeReadWrite if true, readonly folders are disabled